==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_shi.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_shi extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "\u2d30\u2d37\u2d54\u2d49\u2d4e \u2d4f \u2d4d\u2d49\u2d4e\u2d30\u2d54\u2d30\u2d5c" },
            { "aoa", "\u2d3d\u2d61\u2d30\u2d4f\u2d63\u2d30 \u2d4f \u2d30\u2d4f\u2d33\u2d53\u2d4d\u2d30" },
            { "aud", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d53\u2d59\u2d5c\u2d54\u2d30\u2d4d\u2d62\u2d30" },
            { "bhd", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d31\u2d43\u2d54\u2d30\u2d62\u2d4f" },
            { "bif", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d31\u2d53\u2d54\u2d53\u2d4f\u2d37\u2d49" },
            { "bwp", "\u2d30\u2d31\u2d53\u2d4d\u2d30 \u2d4f \u2d31\u2d53\u2d5c\u2d59\u2d61\u2d30\u2d4f\u2d30" },
            { "cad", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d3d\u2d30\u2d4f\u2d30\u2d37\u2d30" },
            { "cdf", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d3d\u2d53\u2d4f\u2d33\u2d53" },
            { "chf", "\u2d30\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d59\u2d61\u2d49\u2d59\u2d54\u2d30" },
            { "cny", "\u2d30\u2d62\u2d30\u2d4f \u2d4f \u2d5b\u2d5b\u2d49\u2d4f\u2d61\u2d30" },
            { "cve", "\u2d49\u2d59\u2d3d\u2d53\u2d37\u2d53 \u2d4f \u2d3d\u2d30\u2d31\u2d31\u2d49\u2d54\u2d37\u2d49" },
            { "djf", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d37\u2d4a\u2d49\u2d31\u2d53\u2d5c\u2d49" },
            { "dzd", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d37\u2d63\u2d30\u2d62\u2d54" },
            { "egp", "\u2d30\u2d4a\u2d4f\u2d49\u2d40 \u2d4f \u2d4e\u2d49\u2d5a\u2d55" },
            { "ern", "\u2d4f\u2d30\u2d3c\u2d3d\u2d30 \u2d4f \u2d49\u2d54\u2d49\u2d5c\u2d49\u2d54\u2d62\u2d30" },
            { "etb", "\u2d31\u2d49\u2d54 \u2d4f \u2d49\u2d5c\u2d62\u2d53\u2d31\u2d62\u2d30" },
            { "eur", "\u2d53\u2d54\u2d53" },
            { "gbp", "\u2d30\u2d4a\u2d4f\u2d49\u2d40 \u2d30\u2d59\u2d5c\u2d54\u2d4d\u2d49\u2d4f\u2d49 \u2d4f \u2d4f\u2d4f\u2d33\u2d4d\u2d49\u2d63" },
            { "ghc", "\u2d59\u2d49\u2d37\u2d49 \u2d4f \u2d56\u2d30\u2d4f\u2d30" },
            { "gmd", "\u2d37\u2d30\u2d4d\u2d30\u2d59\u2d49 \u2d4f \u2d33\u2d30\u2d4e\u2d31\u2d62\u2d30" },
            { "gns", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d56\u2d49\u2d4f\u2d62\u2d30" },
            { "inr", "\u2d30\u2d54\u2d53\u2d31\u2d49 \u2d4f \u2d4d\u2d40\u2d49\u2d4f\u2d37" },
            { "jpy", "\u2d30\u2d62\u2d30\u2d4f \u2d4f \u2d4d\u2d62\u2d30\u2d31\u2d30\u2d4f" },
            { "kes", "\u2d30\u2d5b\u2d49\u2d4d\u2d49\u2d4f \u2d4f \u2d3d\u2d49\u2d4f\u2d62\u2d30" },
            { "kmf", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d47\u2d53\u2d4e\u2d53\u2d55" },
            { "lrd", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d4d\u2d49\u2d31\u2d49\u2d54\u2d62\u2d30" },
            { "lsl", "\u2d4d\u2d53\u2d5c\u2d49 \u2d4f \u2d4d\u2d49\u2d5a\u2d53\u2d5f\u2d53" },
            { "lyd", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d4d\u2d49\u2d31\u2d62\u2d30" },
            { "mad", "\u2d30\u2d37\u2d54\u2d49\u2d4e \u2d4f \u2d4d\u2d4e\u2d56\u2d54\u2d49\u2d31" },
            { "mga", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d4e\u2d30\u2d37\u2d30\u2d56\u2d30\u2d5b\u2d47\u2d30\u2d54" },
            { "mro", "\u2d53\u2d47\u2d49\u2d62\u2d62\u2d30 \u2d4f \u2d4e\u2d53\u2d55\u2d49\u2d5f\u2d30\u2d4f\u2d62\u2d30 (1973\u20132017)" },
            { "mru", "\u2d53\u2d47\u2d49\u2d62\u2d62\u2d30 \u2d4f \u2d4e\u2d53\u2d55\u2d49\u2d5f\u2d30\u2d4f\u2d62\u2d30" },
            { "mur", "\u2d30\u2d54\u2d53\u2d31\u2d49 \u2d4f \u2d4e\u2d53\u2d54\u2d49\u2d59" },
            { "mwk", "\u2d3d\u2d61\u2d30\u2d5b\u2d30 \u2d4f \u2d4e\u2d30\u2d4d\u2d30\u2d61\u2d49" },
            { "mzm", "\u2d30\u2d4e\u2d49\u2d5c\u2d49\u2d3d\u2d4d \u2d4f \u2d4e\u2d53\u2d63\u2d4f\u2d31\u2d49\u2d47" },
            { "nad", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d4f\u2d30\u2d4e\u2d49\u2d31\u2d62\u2d30" },
            { "ngn", "\u2d4f\u2d30\u2d62\u2d54\u2d30 \u2d4f \u2d4f\u2d49\u2d4a\u2d49\u2d54\u2d62\u2d30" },
            { "rwf", "\u2d30\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d54\u2d61\u2d30\u2d4f\u2d37\u2d30" },
            { "sar", "\u2d30\u2d54\u2d62\u2d30\u2d4d \u2d4f \u2d59\u2d59\u2d30\u2d44\u2d53\u2d37\u2d49\u2d62\u2d30" },
            { "scr", "\u2d30\u2d54\u2d53\u2d31\u2d49 \u2d4f \u2d59\u2d59\u2d49\u2d5b\u2d49\u2d4d" },
            { "sdg", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d59\u2d59\u2d53\u2d37\u2d30\u2d4f" },
            { "sdp", "\u2d30\u2d4a\u2d4f\u2d49\u2d40 \u2d4f \u2d59\u2d59\u2d53\u2d37\u2d30\u2d4f" },
            { "shp", "\u2d30\u2d4a\u2d4f\u2d49\u2d40 \u2d4f \u2d59\u2d30\u2d4f\u2d5c\u2d49\u2d4d\u2d49\u2d4f" },
            { "sll", "\u2d4d\u2d49\u2d62\u2d53\u2d4f" },
            { "sos", "\u2d30\u2d5b\u2d49\u2d4d\u2d49\u2d4f \u2d4f \u2d5a\u2d5a\u2d53\u2d4e\u2d30\u2d4d" },
            { "std", "\u2d30\u2d37\u2d53\u2d31\u2d54\u2d30 \u2d4f \u2d59\u2d30\u2d4f\u2d5f\u2d53\u2d4e\u2d49 (1977\u20132017)" },
            { "stn", "\u2d30\u2d37\u2d53\u2d31\u2d54\u2d30 \u2d4f \u2d59\u2d30\u2d4f\u2d5f\u2d53\u2d4e\u2d49" },
            { "szl", "\u2d4d\u2d49\u2d4d\u2d30\u2d4f\u2d4a\u2d49\u2d4f\u2d49" },
            { "tnd", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d5c\u2d53\u2d4f\u2d59" },
            { "tzs", "\u2d30\u2d5b\u2d49\u2d4d\u2d49\u2d4f \u2d4f \u2d5f\u2d30\u2d4f\u2d65\u2d30\u2d4f\u2d62\u2d30" },
            { "ugx", "\u2d30\u2d5b\u2d49\u2d4d\u2d49\u2d4f \u2d4f \u2d53\u2d56\u2d30\u2d4f\u2d37\u2d30" },
            { "usd", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d49\u2d61\u2d53\u2d4f\u2d30\u2d3d \u2d49\u2d4e\u2d53\u2d4f\u2d4f" },
            { "xaf", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d5a\u2d49\u2d3c\u2d30" },
            { "xof", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d5a\u2d49\u2d3c\u2d30 \u2d31\u2d49\u2d59\u2d30\u2d61" },
            { "zar", "\u2d30\u2d54\u2d30\u2d4f\u2d37 \u2d4f \u2d30\u2d3c\u2d54\u2d49\u2d47\u2d62\u2d30 \u2d4f \u2d49\u2d3c\u2d3c\u2d53\u2d59" },
            { "zmk", "\u2d30\u2d3d\u2d61\u2d30\u2d5b\u2d30 \u2d4f \u2d63\u2d30\u2d4e\u2d31\u2d62\u2d30 (1968\u20132012)" },
            { "zmw", "\u2d30\u2d3d\u2d61\u2d30\u2d5b\u2d30 \u2d4f \u2d63\u2d30\u2d4e\u2d31\u2d62\u2d30" },
            { "zwd", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d63\u2d49\u2d4e\u2d31\u2d30\u2d31\u2d61\u2d49" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1.1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_shi.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_shi extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "\u2d30\u2d37\u2d54\u2d49\u2d4e \u2d4f \u2d4d\u2d49\u2d4e\u2d30\u2d54\u2d30\u2d5c" },
            { "aoa", "\u2d3d\u2d61\u2d30\u2d4f\u2d63\u2d30 \u2d4f \u2d30\u2d4f\u2d33\u2d53\u2d4d\u2d30" },
            { "aud", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d53\u2d59\u2d5c\u2d54\u2d30\u2d4d\u2d62\u2d30" },
            { "bhd", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d31\u2d43\u2d54\u2d30\u2d62\u2d4f" },
            { "bif", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d31\u2d53\u2d54\u2d53\u2d4f\u2d37\u2d49" },
            { "bwp", "\u2d30\u2d31\u2d53\u2d4d\u2d30 \u2d4f \u2d31\u2d53\u2d5c\u2d59\u2d61\u2d30\u2d4f\u2d30" },
            { "cad", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d3d\u2d30\u2d4f\u2d30\u2d37\u2d30" },
            { "cdf", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d3d\u2d53\u2d4f\u2d33\u2d53" },
            { "chf", "\u2d30\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d59\u2d61\u2d49\u2d59\u2d54\u2d30" },
            { "cny", "\u2d30\u2d62\u2d30\u2d4f \u2d4f \u2d5b\u2d5b\u2d49\u2d4f\u2d61\u2d30" },
            { "cve", "\u2d49\u2d59\u2d3d\u2d53\u2d37\u2d53 \u2d4f \u2d3d\u2d30\u2d31\u2d31\u2d49\u2d54\u2d37\u2d49" },
            { "djf", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d37\u2d4a\u2d49\u2d31\u2d53\u2d5c\u2d49" },
            { "dzd", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d37\u2d63\u2d30\u2d62\u2d54" },
            { "egp", "\u2d30\u2d4a\u2d4f\u2d49\u2d40 \u2d4f \u2d4e\u2d49\u2d5a\u2d55" },
            { "ern", "\u2d4f\u2d30\u2d3c\u2d3d\u2d30 \u2d4f \u2d49\u2d54\u2d49\u2d5c\u2d49\u2d54\u2d62\u2d30" },
            { "etb", "\u2d31\u2d49\u2d54 \u2d4f \u2d49\u2d5c\u2d62\u2d53\u2d31\u2d62\u2d30" },
            { "eur", "\u2d53\u2d54\u2d53" },
            { "gbp", "\u2d30\u2d4a\u2d4f\u2d49\u2d40 \u2d30\u2d59\u2d5c\u2d54\u2d4d\u2d49\u2d4f\u2d49 \u2d4f \u2d4f\u2d4f\u2d33\u2d4d\u2d49\u2d63" },
            { "ghc", "\u2d59\u2d49\u2d37\u2d49 \u2d4f \u2d56\u2d30\u2d4f\u2d30" },
            { "gmd", "\u2d37\u2d30\u2d4d\u2d30\u2d59\u2d49 \u2d4f \u2d33\u2d30\u2d4e\u2d31\u2d62\u2d30" },
            { "gns", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d56\u2d49\u2d4f\u2d62\u2d30" },
            { "inr", "\u2d30\u2d54\u2d53\u2d31\u2d49 \u2d4f \u2d4d\u2d40\u2d49\u2d4f\u2d37" },
            { "jpy", "\u2d30\u2d62\u2d30\u2d4f \u2d4f \u2d4d\u2d62\u2d30\u2d31\u2d30\u2d4f" },
            { "kes", "\u2d30\u2d5b\u2d49\u2d4d\u2d49\u2d4f \u2d4f \u2d3d\u2d49\u2d4f\u2d62\u2d30" },
            { "kmf", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d47\u2d53\u2d4e\u2d53\u2d55" },
            { "lrd", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d4d\u2d49\u2d31\u2d49\u2d54\u2d62\u2d30" },
            { "lsl", "\u2d4d\u2d53\u2d5c\u2d49 \u2d4f \u2d4d\u2d49\u2d5a\u2d53\u2d5f\u2d53" },
            { "lyd", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d4d\u2d49\u2d31\u2d62\u2d30" },
            { "mad", "\u2d30\u2d37\u2d54\u2d49\u2d4e \u2d4f \u2d4d\u2d4e\u2d56\u2d54\u2d49\u2d31" },
            { "mga", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d4e\u2d30\u2d37\u2d30\u2d56\u2d30\u2d5b\u2d47\u2d30\u2d54" },
            { "mro", "\u2d53\u2d47\u2d49\u2d62\u2d62\u2d30 \u2d4f \u2d4e\u2d53\u2d55\u2d49\u2d5f\u2d30\u2d4f\u2d62\u2d30 (1973\u20132017)" },
            { "mru", "\u2d53\u2d47\u2d49\u2d62\u2d62\u2d30 \u2d4f \u2d4e\u2d53\u2d55\u2d49\u2d5f\u2d30\u2d4f\u2d62\u2d30" },
            { "mur", "\u2d30\u2d54\u2d53\u2d31\u2d49 \u2d4f \u2d4e\u2d53\u2d54\u2d49\u2d59" },
            { "mwk", "\u2d3d\u2d61\u2d30\u2d5b\u2d30 \u2d4f \u2d4e\u2d30\u2d4d\u2d30\u2d61\u2d49" },
            { "mzm", "\u2d30\u2d4e\u2d49\u2d5c\u2d49\u2d3d\u2d4d \u2d4f \u2d4e\u2d53\u2d63\u2d4f\u2d31\u2d49\u2d47" },
            { "nad", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d4f\u2d30\u2d4e\u2d49\u2d31\u2d62\u2d30" },
            { "ngn", "\u2d4f\u2d30\u2d62\u2d54\u2d30 \u2d4f \u2d4f\u2d49\u2d4a\u2d49\u2d54\u2d62\u2d30" },
            { "rwf", "\u2d30\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d4f \u2d54\u2d61\u2d30\u2d4f\u2d37\u2d30" },
            { "sar", "\u2d30\u2d54\u2d62\u2d30\u2d4d \u2d4f \u2d59\u2d59\u2d30\u2d44\u2d53\u2d37\u2d49\u2d62\u2d30" },
            { "scr", "\u2d30\u2d54\u2d53\u2d31\u2d49 \u2d4f \u2d59\u2d59\u2d49\u2d5b\u2d49\u2d4d" },
            { "sdg", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d59\u2d59\u2d53\u2d37\u2d30\u2d4f" },
            { "sdp", "\u2d30\u2d4a\u2d4f\u2d49\u2d40 \u2d4f \u2d59\u2d59\u2d53\u2d37\u2d30\u2d4f" },
            { "shp", "\u2d30\u2d4a\u2d4f\u2d49\u2d40 \u2d4f \u2d59\u2d30\u2d4f\u2d5c\u2d49\u2d4d\u2d49\u2d4f" },
            { "sle", "\u2d4d\u2d49\u2d62\u2d53\u2d4f" },
            { "sll", "\u2d4d\u2d49\u2d62\u2d53\u2d4f (1964\u20142022)" },
            { "sos", "\u2d30\u2d5b\u2d49\u2d4d\u2d49\u2d4f \u2d4f \u2d5a\u2d5a\u2d53\u2d4e\u2d30\u2d4d" },
            { "std", "\u2d30\u2d37\u2d53\u2d31\u2d54\u2d30 \u2d4f \u2d59\u2d30\u2d4f\u2d5f\u2d53\u2d4e\u2d49 (1977\u20132017)" },
            { "stn", "\u2d30\u2d37\u2d53\u2d31\u2d54\u2d30 \u2d4f \u2d59\u2d30\u2d4f\u2d5f\u2d53\u2d4e\u2d49" },
            { "szl", "\u2d4d\u2d49\u2d4d\u2d30\u2d4f\u2d4a\u2d49\u2d4f\u2d49" },
            { "tnd", "\u2d30\u2d37\u2d49\u2d4f\u2d30\u2d54 \u2d4f \u2d5c\u2d53\u2d4f\u2d59" },
            { "tzs", "\u2d30\u2d5b\u2d49\u2d4d\u2d49\u2d4f \u2d4f \u2d5f\u2d30\u2d4f\u2d65\u2d30\u2d4f\u2d62\u2d30" },
            { "ugx", "\u2d30\u2d5b\u2d49\u2d4d\u2d49\u2d4f \u2d4f \u2d53\u2d56\u2d30\u2d4f\u2d37\u2d30" },
            { "usd", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d49\u2d61\u2d53\u2d4f\u2d30\u2d3d \u2d49\u2d4e\u2d53\u2d4f\u2d4f" },
            { "xaf", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d5a\u2d49\u2d3c\u2d30" },
            { "xof", "\u2d3c\u2d54\u2d30\u2d4f\u2d3d \u2d5a\u2d49\u2d3c\u2d30 \u2d31\u2d49\u2d59\u2d30\u2d61" },
            { "zar", "\u2d30\u2d54\u2d30\u2d4f\u2d37 \u2d4f \u2d30\u2d3c\u2d54\u2d49\u2d47\u2d62\u2d30 \u2d4f \u2d49\u2d3c\u2d3c\u2d53\u2d59" },
            { "zmk", "\u2d30\u2d3d\u2d61\u2d30\u2d5b\u2d30 \u2d4f \u2d63\u2d30\u2d4e\u2d31\u2d62\u2d30 (1968\u20132012)" },
            { "zmw", "\u2d30\u2d3d\u2d61\u2d30\u2d5b\u2d30 \u2d4f \u2d63\u2d30\u2d4e\u2d31\u2d62\u2d30" },
            { "zwd", "\u2d30\u2d37\u2d53\u2d4d\u2d30\u2d54 \u2d4f \u2d63\u2d49\u2d4e\u2d31\u2d30\u2d31\u2d61\u2d49" },
        };
        return data;
    }
}
